{
  description = "NixOS configuration flake";

  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-24.11";
    disko.url = "github:nix-community/disko";
    disko.inputs.nixpkgs.follows = "nixpkgs";
    home-manager.url = "github:nix-community/home-manager/release-24.11";
    home-manager.inputs.nixpkgs.follows = "nixpkgs";
    nixvim = {
      url = "github:nix-community/nixvim/nixos-24.11";
      inputs = {
        nixpkgs.follows = "nixpkgs";
        devshell.follows = "";
        flake-compat.follows = "";
        git-hooks.follows = "";
        home-manager.follows = "";
        nix-darwin.follows = "";
        treefmt-nix.follows = "";
      };
    };
  };

  outputs = { self, nixpkgs, home-manager, disko, nixvim, ...}:
    let
      system = "x86_64-linux";
      pkgs = nixpkgs.legacyPackages.${system};
    in {
      nixosConfigurations = {
        lift = nixpkgs.lib.nixosSystem {
          inherit system;
          modules = [
            ./configuration.nix
            ./sway.nix
            ./hardware-configuration.nix
          ];
        };
        tien = nixpkgs.lib.nixosSystem {
          inherit system;
          modules = [
            disko.nixosModules.disko
            ./vps-configuration.nix
            ./vps-hardware-configuration.nix
          ];
        };
      };
      homeConfigurations = {
        "rothe@lift" = home-manager.lib.homeManagerConfiguration {
          inherit pkgs;
          modules = [
            ./home/terminal
            ./home/wayland
            nixvim.homeManagerModules.nixvim
          ];
          extraSpecialArgs = {
            mail = nixpkgs.lib.strings.concatStrings ["mail" "@" "johannes-rothe.de"];
          };
        };
        "rothe@johannes-powermachine" = home-manager.lib.homeManagerConfiguration {
          inherit pkgs;
          modules = [
            ./home/terminal
            nixvim.homeManagerModules.nixvim
          ];
          extraSpecialArgs = {
            mail = nixpkgs.lib.strings.concatStrings ["mail" "@" "johannes-rothe.de"];
          };
        };
        "rothe@pdemu1cml000301" = home-manager.lib.homeManagerConfiguration {
          inherit pkgs;
          modules = [
            ./home/terminal
            nixvim.homeManagerModules.nixvim
          ];
          extraSpecialArgs = {
            mail = nixpkgs.lib.strings.concatStrings ["rothe" "@" "magazino.eu"];
          };
        };
      };
    };
}
